<? die(); ?>
# il segno di cancelletto all'inizio della linea indica i commenti;
# ogni linea e' un'espressione regolare che identifica un termine ritenuto spam.
phentermine
dospan
roulette
gotboredom
cialis
kiomono
alprazolam
fioricet
bestbuy
tramadol
lortab
ativan
ambien
tamiflu
valium
valb
viagra
levitra
xanax
tramadol
hycodrone
soma-online
hydrocodone
adipex
a-gas
aput
apyrin
arcjet
arctg
byplay
5000megs
sex
lesbo
lesbian
gay
janecelka
bondage

#sites
bombets\.org
bombey7\.org
volimar\.org
ah2own\.org
fot53\.org
bolshenepiy\.org
valtbess\.org
pij0n\.org
kolomrt\.org
myboard\.info

#html
(a)\s*(href)
(<\s*\/\s*a\s*>)